==> haskell-process-extras-0.7.4-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-process-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: process-extras
version: 0.7.4
id: process-extras-0.7.4-53UOCR1V5MMGVACTu8aFtq
key: process-extras-0.7.4-53UOCR1V5MMGVACTu8aFtq
license: MIT
maintainer: David Fox <dsf@seereason.com>
author: David Lazar, Bas van Dijk, David Fox
homepage: https://github.com/seereason/process-extras
synopsis: Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.
category: System
abi: 6313115f63e982ce8e4e4a41e73c76a4
exposed: True
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Builder
    System.Process.Text.Lazy
hidden-modules: Utils
import-dirs: /usr/lib/ghc-8.4.3/site-local/process-extras-0.7.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/process-extras-0.7.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/process-extras-0.7.4
hs-libraries: HSprocess-extras-0.7.4-53UOCR1V5MMGVACTu8aFtq
depends:
    base-4.11.1.0 data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0
    ListLike-4.6-CqbsYp4FexjGX2KY2TVvvV mtl-2.2.2 process-1.6.3.0
    bytestring-0.10.8.2 text-1.2.3.0 deepseq-1.4.3.0
    generic-deriving-1.12.2-6DLzDNi0rWHKIezusQA75Q
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=df69bf1546f6b4e11e877584feeeb61a
             ListLike-4.6-CqbsYp4FexjGX2KY2TVvvV=33980d90f01c8f2cede18decb5c810e9
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             generic-deriving-1.12.2-6DLzDNi0rWHKIezusQA75Q=5b6797d06cb2f072e904519421e65762
haddock-interfaces: /usr/share/doc/haskell-process-extras/html/process-extras.haddock
haddock-html: /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-process-extras-0.7.4-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-process-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: process-extras
version: 0.7.4
id: process-extras-0.7.4-8JCyXf4fy9vDvCZkdeBohB
key: process-extras-0.7.4-8JCyXf4fy9vDvCZkdeBohB
license: MIT
maintainer: David Fox <dsf@seereason.com>
author: David Lazar, Bas van Dijk, David Fox
homepage: https://github.com/seereason/process-extras
synopsis: Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.
category: System
abi: de497ededbc254b9ba3ba04c5286ffb3
exposed: True
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Builder
    System.Process.Text.Lazy
hidden-modules: Utils
import-dirs: /usr/lib/ghc-8.4.3/site-local/process-extras-0.7.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/process-extras-0.7.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/process-extras-0.7.4
hs-libraries: HSprocess-extras-0.7.4-8JCyXf4fy9vDvCZkdeBohB
depends:
    base-4.11.1.0 data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0
    ListLike-4.6-CqbsYp4FexjGX2KY2TVvvV mtl-2.2.2 process-1.6.3.0
    bytestring-0.10.8.2 text-1.2.3.0 deepseq-1.4.3.0
    generic-deriving-1.12.2-Lpa3NRyybyM3M3nKmCGQ5w
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=df69bf1546f6b4e11e877584feeeb61a
             ListLike-4.6-CqbsYp4FexjGX2KY2TVvvV=33980d90f01c8f2cede18decb5c810e9
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             generic-deriving-1.12.2-Lpa3NRyybyM3M3nKmCGQ5w=d64742e0f0ea76bcc4ecdb511ce9d0c2
haddock-interfaces: /usr/share/doc/haskell-process-extras/html/process-extras.haddock
haddock-html: /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
